mlpy.cli package
================

.. automodule:: mlpy.cli
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   mlpy.cli.commands
   mlpy.cli.main
